Some dummy data for testing. Possible that none of these are used anywhere.
Keep for any possible use cases in future versions.

### Example

* Add any of these files for a unit test in `tests/` directory.
* Use `python -m pytest [...]`, which adds current directory to `sys.path` *[source](https://docs.pytest.org/en/latest/usage.html#cmdline)*.